"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'cc-agent-helper'
__description__ = 'agent helper package'
__version__ = '0.0.1'
__author__ = 'Cockroach Creative'
__author_email__ = 'support@cockreative.com'
__license__ = 'Apache 2.0'
__url__ = 'https://cockreative.com/'
